from django.contrib.auth import views, login
from django.views.generic import CreateView
from django.shortcuts import redirect
from django.urls import reverse_lazy

from accounts.forms import LoginForm, RegisterForm
from accounts.models import User


class AuthSuccessUrlMixin:
    def get_success_url(self):
        return self.request.GET.get(
            'next',
            self.request.POST.get(
                'next',
                reverse_lazy('main_page')
            )
        )


class LoginView(AuthSuccessUrlMixin, views.LoginView):
    template_name = 'login.html'
    form_class = LoginForm


class LogoutView(views.LogoutView):
    def get_next_page(self):
        return self.request.META.get('HTTP_REFERER')


class RegisterView(AuthSuccessUrlMixin, CreateView):
    model = User
    template_name = 'registration.html'
    form_class = RegisterForm

    def form_valid(self, form):
        user = form.save()
        login(self.request, user)
        return redirect(self.get_success_url())
